<div class="mobile-menubar">
  <button id="toggle-menu" aria-controls="sidebar" aria-expanded="false">☰ Menu</button>
  <div class="spacer"></div>
  <div>
    <a href="#top">Back to top</a>
  </div>
</div>
