<div class="prev-next-links">
  {% if prev %}
    <a href="{{ prev.link|e }}">
      <span class="prev-next-caption">Previous</span>
      <span>{{ prev.title }}</span>
    </a>
  {% else %}
    <span></span>
  {% endif %}
  {% if next %}
    <a href="{{ next.link|e }}" class="next-page">
      <span class="prev-next-caption">Next page</span>
      <span>{{ next.title }}</span>
    </a>
  {% else %}
    <span></span>
  {% endif %}
</div>
