<h3>
  <a href="{{ pathto(root_doc) |e }}">{{ project }} <span class="visually-hidden">table of contents</span></a>
</h3>
{{ toctree(includehidden=theme_globaltoc_includehidden, collapse=theme_globaltoc_collapse, maxdepth=theme_globaltoc_maxdepth) }}
